HostTimingInfo

Struct HostTimingInfo 

pub struct HostTimingInfo {
    pub fno: usize,
    pub datetime: DateTime<Utc>,
}
Timing information acquired on the host computer.

This can be considered the “least common denominator” of frame timing information, as it will always be present but is not necessarily as accurate as desired.

Fields

fno: usize

The frame number as counted by the host.

This can deviate from the “real” frame number if the frames were dropped, as might happen if the computer was busy with a different task.

datetime: DateTime<Utc>

The timestamp of the frame when it was acquired by the host.

This will be at least slightly delayed from the “real” frame timestamp by transmission delays. Furthermore, if the computer was busy during acquisition there may be additional, highly variable, delays.